@@ -411,7 +411,7 @@ def dtypes(t=None):
         df = pipein()
         newdf = pd.DataFrame(pd.Series(df.columns), columns=["column"])
         newdf["dtype"] = pd.Series([str(e) for e in df.dtypes])
-        pipeout(newdf)
+        pipeout(newdf.T, header=False)
     else:
         df = pipein().select_dtypes(t)
         pipeout(df)
@@ -809,6 +809,10 @@ def merge(fname1, fname2, how="inner", on=None):
 
 @register
 def tab():
+    """Equivalent to `ph to tsv`.
+
+    Usage: cat a.csv | ph tab
+    """
     pipeout(pipein(), sep="\t")
 
 
@@ -989,8 +993,37 @@ def open_(ftype, fname, **kwargs):
     pipeout(df)
 
 
+_ATTRS_WITH_SERIES_OUTPUT = (
+    "all",
+    "any",
+    "count",
+    "kurt",
+    "kurtosis",
+    "mad",
+    "mean",
+    "median",
+    "min",
+    "nunique",
+    "prod",
+    "product",
+    "quantile",
+    "sem",
+    "skew",
+    "std",
+    "sum",
+    "var",
+)
+
+
 def _call(attr, *args, **kwargs):
-    pipeout(getattr(pipein(), attr)(*args, **kwargs))
+    df = pipein()
+    dfn = getattr(df, attr)(*args, **kwargs)
+    if attr in _ATTRS_WITH_SERIES_OUTPUT:
+        dfn = dfn.reset_index()
+        dfn = dfn.T
+        pipeout(dfn, header=False)
+    else:
+        pipeout(dfn)
 
 
 def register_forward(attr):
@@ -1004,6 +1037,10 @@ def head(n=10):
     Print the header followed by the first 10 (or n) lines of the stream to
     standard output.
 
+    Usage: cat a.csv | ph head
+           cat a.csv | ph head 8
+
+
     """
     _call("head", int(n))
 
@@ -1099,12 +1136,49 @@ def columns(*cols, **kwargs):
         if col not in df.columns:
             exit("No such column {}".format(col))
 
+    print("columns")
     if not cols and not kwargs:
         print("\n".join(list(df.columns)))
     else:
         pipeout(df[cols])
 
 
+@register
+def drop(*columns, **kwargs):
+    """Drop specified labels from rows or columns.
+
+    Remove rows or columns by specifying label names and corresponding
+    axis, or by specifying directly index or column names.
+
+    Usage: cat a.csv | ph drop 'x' --axis=columns
+           cat a.csv | ph drop 0   --axis=index
+
+    """
+    for opt in ("axis", "levels"):
+        if opt in kwargs:
+            kwargs[opt] = __tryparse(kwargs[opt])
+    if "inplace" in kwargs:
+        exit("inplace in nonsensical in ph")
+
+    df = pipein()
+
+    if kwargs.get("axis") in (None, 0, "index"):
+        columns = [__tryparse(col) for col in columns]
+    elif kwargs.get("axis") in (1, "columns"):
+        for col in columns:
+            if not col in df.columns:
+                exit("Unknown column {}.".format(col))
+    else:
+        exit(
+            "--axis=index (or 0) or --axis=columns (or 1), not {}".format(
+                kwargs.get("axis")
+            )
+        )
+
+    ndf = df.drop(list(columns), **kwargs)
+    pipeout(ndf)
+
+
 @register
 def shape():
     """Print the shape of the csv file, i.e. num cols and num rows.
@@ -1179,49 +1253,25 @@ def polyfit(x, y, deg=1):
     pipeout(df)
 
 
-pandas_computations = [
-    "abs",
-    "all",
-    "any",
-    "clip",
-    "corr",
-    "count",
-    "cov",
-    "cummax",
-    "cummin",
-    "cumprod",
-    "cumsum",
-    "diff",
-    "kurt",
-    "kurtosis",
-    "mad",
-    "max",
-    "mean",
-    "median",
-    "min",
-    "mode",
-    "pct_change",
-    "prod",
-    "product",
-    "quantile",
-    "rank",
-    "round",
-    "sem",
-    "skew",
-    "sum",
-    "std",
-    "var",
-    "nunique",
-    "transpose",
-]
-for attr in pandas_computations:
-    register_forward(attr)
+def __process(attr):
+    if attr in COMMANDS:
+        return False
+    if attr.startswith("_"):
+        return False
+    if attr.startswith("to_"):
+        return False
+    return True
 
 
-def main():
-    if len(sys.argv) < 2:
+for attr in dir(pd.DataFrame):
+    if __process(attr):
+        register_forward(attr)
+
+
+def _main(argv):
+    if len(argv) < 2:
         exit("Usage: ph command [args]\n       ph help")
-    cmd = sys.argv[1]
+    cmd = argv[1]
     if cmd in ("-v", "--version"):
         print_version()
         exit()
@@ -1233,7 +1283,7 @@ def main():
     # Arguments of type "--abc=def" go into kwargs as key, value pairs
     args = []
     kwarg = {}
-    for a in sys.argv[2:]:
+    for a in argv[2:]:
         if KWARG.match(a):
             args.append(a)
         elif KWARG_WITH_VALUE.match(a):
@@ -1242,12 +1292,16 @@ def main():
             v = a[split + 1 :]
             kwarg[k] = v
         else:
-            args.append(a)
+            args.append(__tryparse(a))
     try:
         COMMANDS[cmd](*args, **kwarg)
     except TypeError as err:
         exit(err)
 
 
+def main():
+    _main(sys.argv)
+
+
 if __name__ == "__main__":
     main()
